Learn R Programming

gooseR (version 0.1.2)

gooseR-package: gooseR: R Integration for 'Goose' AI

Description

Seamless integration between R and 'Goose' AI capabilities including memory management, visualization enhancements, and workflow automation. Save R objects to 'Goose' memory, apply Block branding to visualizations, and manage data science project workflows. For more information about 'Goose' AI, see https://github.com/block/goose.

Arguments

Author

Maintainer: Brandon Theriault btheriault@block.xyz